buckygen: Efficient generation of nonisomorphic fullerenes
==========================================================

Description
-----------

Buckygen is a program for the efficient generation of all nonisomorphic
fullerenes. These are triangulations where all vertices have degree 5 or
6. Or if the dual representation is used: cubic plane graphs where all
faces are pentagons or hexagons.

License
-------

Buckygen is licensed under the GNU General Public License v3 (June 2007)


Upstream Contact
----------------

Buckygen was mainly written by Jan Goedgebeur,
jan.goedgebeur[at]ugent.be.

http://caagt.ugent.be/buckygen/
